@@ -11,7 +11,6 @@ import os
 
 from ..funkplot.funkplot import FunkPlot
 from ..funkbot.funkbot   import FunkBot
-from ..utils.utils       import _GetVal
 
 class FunkHandler(socketserver.BaseRequestHandler):
     """
@@ -27,7 +26,7 @@ class FunkHandler(socketserver.BaseRequestHandler):
         data = self.request[0].strip()
 
         # Debug message.
-        print(f"New message from server {self.client_address[0]}")
+        #print(f"New message from server {self.client_address[0]}")
 
         # Table data.
         table=json.loads(data)
@@ -50,13 +49,17 @@ class FunkSocket(socketserver.UDPServer):
     UDP socket server. It inherits "socketserver.UDPServer".
     """
 
-    def __init__(self, Host="127.0.0.1", Port=10123) -> None:
+    def __init__(self, Host="127.0.0.1", Port=10042) -> None:
 
         super().__init__((Host, Port), FunkHandler)
 
         self.host=Host
         self.port=Port
 
+        # Enable reuse, in case the restart was too fast and the port was still in TIME_WAIT.
+        self.allow_reuse_address=True
+        self.max_packet_size=65504
+
         self.funkbot=None
         self.funkplot=None
 
@@ -95,7 +98,7 @@ class FunkSocket(socketserver.UDPServer):
             os._exit(0)
 
 
-    def EvalData(self, table):
+    def EvalData(self, table: dict):
         """Evaluate data received from socket. You might want to overwrite this function."""
 
         # Debug info.
@@ -104,20 +107,34 @@ class FunkSocket(socketserver.UDPServer):
             print(table)
             print("--------------------------------------")
 
-        # Treat different cases.
-        if "dataType" in table:
+        key="command"
+        textmessage="moose_text"
+        bombresult="moose_bomb_result"
+        straferesult="moose_strafe_result"
+        lsograde="moose_lso_grade"
 
-            if table["dataType"]=="Text Message":
-                print("Got text message!")
+        table.get
+
+        # Treat different cases.
+        if key in table:
+
+            command=table.get(key, "")
+            server=table.get("server_name", "unknown")
+
+            # Debug info
+            print(f"Got {command} from server {server}!")
+
+            if command==textmessage:
+                #print("Got text message!")
 
                 # Extract text.
-                text=table["text"]
+                text=table.get("text", " ")
 
                 # Send text to Discord.
                 self.funkbot.SendText(text, self.channelIDmessage)
 
-            if table["dataType"]=="Bomb Result":
-                print("Got bomb result!")
+            elif command==bombresult:
+                #print("Got bomb result!")
 
                 # Create bomb run figure.
                 fig, ax=self.funkplot.PlotBombRun(table)
@@ -125,8 +142,8 @@ class FunkSocket(socketserver.UDPServer):
                 # Send figure to Discord.
                 self.funkbot.SendFig(fig, self.channelIDrange)
 
-            elif table["dataType"]=="Strafe Result":
-                print("Got strafe result!")
+            elif command==straferesult:
+                #print("Got strafe result!")
 
                 # Create strafe run figure.
                 fig, ax=self.funkplot.PlotStrafeRun(table)
@@ -134,8 +151,8 @@ class FunkSocket(socketserver.UDPServer):
                 # Send figure to discord.
                 self.funkbot.SendFig(fig, self.channelIDrange)
 
-            elif table["dataType"]=="Trap Sheet":
-                print("Got trap sheet!")
+            elif command==lsograde:
+                #print("Got trap sheet!")
 
                 # Send LSO grade.
                 self.funkbot.SendLSOEmbed(table, self.channelIDairboss)
@@ -147,7 +164,7 @@ class FunkSocket(socketserver.UDPServer):
                 self.funkbot.SendFig(fig, self.channelIDairboss)
 
             else:
-                print("ERROR: Unknown data type in table!")
+                print(f"WARNING: Unknown command in table: {command}")
         else:
-            print("ERROR: dataType not key in table!")
+            print("WARNING: not key command in table!")
             print(table)
\ No newline at end of file
